atconfig(1M)

/usr/etc/appletalk/atconfig - enable AppleTalk on an interface

As shipped in IRIX 6.5.30. Last changed in IRIX 6.5.15.

     NAME
          /usr/etc/appletalk/atconfig - enable AppleTalk on an
          interface

     SYNOPSIS
          atconfig intr [-net n] [-optnet n] [-optstart sn -optend en]
          [-node d] [-start sn -end en] [-f] [-D]
          atconfig -clear
          atconfig -attach intr

     DESCRIPTION
          The atconfig command enables AppleTalk on an interface.  It
          is similar in function to ifconfig(1m).  When atconfig is
          run, the interface uses the Apple Address Resolution
          Protocol (AARP) to determine its net and node number.  When
          run on the loopback lo0, atconfig sets the net and node of a
          local pseudo-network.  Specifying a intr of "default" will
          configure the first interface in the ifaddr list.  All
          numeric arguments may be specified in hexadecimal by
          prepending them with a 0x.  The flags are defined as
          follows:

          -net n
               Specifies that atconfig will use net number n. If a net
               number is specified, and it conflicts with net
               information gathered from RTMP packets, EINVAL will be
               returned.  A net number must be specified when
               configuring the loopback interface (lo0).

          -optnet n
               Specifies that atconfig will use net number n, net
               range n-n. This differs from -net in that if there is
               another router using a different net number, no error
               message will be returned.  If -optstart and -optend are
               used, they specify a network range to be used only if
               it does not conflict with an existing router.  These
               modes are  useful for configuring K-Talk on a network
               where other AppleTalk routers exist, but are not
               reliable.

          -node d
               This specifies that AARP will begin trying to acquire a
               node number at node d. If the node number is not
               specified, it defaults to 128 (0x80).  It does not
               specify the actual node number obtained, only where to
               start.

          -start sn -end en
               This specifies the start and end of the network range.
               These arguments are only used when you want to set up
               an extended network range (more than one node number).
               If the start and end are not specified, atconfig
               defaults to the range already in use on the network (if
               there are other routers), or to provisional mode there
               are no other routers.  In provisional mode, network
               range 65280-65534 (the provisional range) is used.
               This will allow K-Talk to communicate with other
               AppleTalk devices on an Ethertalk network with no
               routers.

          -f   specifies that atconfig will use the specified net
               number for the local pseudo-net even if it already
               appears in routing tables.  This option is used to
               maintain single numbers for the pseudo-net when there
               are routers that do not properly process delete-route
               packets.

          -D   causes debugging information to be printed first when
               the flag is encountered in the command line, and again
               when the arguments have been processed.  It is mostly
               used to check argument parsing.

          -clear
               is used to reset all AppleTalk kernel information.  It
               should be done only when all AppleTalk services have
               been halted (with an atinit halt).  It will clear all
               interface configuration information, as well as the
               AARP and routing tables. After clearing the interface,
               you should wait for 10 seconds to allow the routing
               tables to be rebuilt before running any additional
               atconfig commands.  The main use of the -clear option
               is to clear a configuration when you plan to switch
               your network configuration.

          -attach
               is used on Streams implementations (currently, only
               Solaris) to make an interface ``known'' by the
               AppleTalk Protocol, but does not configure it.  This is
               used to allow routing packets through on an interface
               in order to determine the prefered net range.  On these
               systems, an interface will not show up in the atinfo(1)
               list until it has either been attached or configured.

     DIAGNOSTICS
          atconfig: old-style arguments.  New command would be: ...
                    The arguments passed to atconfig were in the
                    format of old versions of atconfig A new-style
                    command line will be printed to ease conversion.

          atconfig: permission denied
                    You must be root to configure interfaces.

          atconfig: socket: ...
                    atconfig could not open an AppleTalk socket.  This
                    usually means that AppleTalk is not installed in
                    the kernel.

          atconfig: invalid interface xx
                    The specified interface is not valid.  Use
                    atinfo(1) to get a list of the interfaces.

          atconfig: interface xx already configured
                    The interface is already configured.  You must
                    clear it with atconfig -clear before you can
                    configure it again.

          atconfig: no net number specified on net with no other routers
                    This means that you did not specify a net number
                    on a network that does not have any other
                    AppleTalk routers.  You need to specify a network
                    number with a -net flag.  To do this, edit
                    /usr/etc/appletalk/services and change the
                    atconfig line for the interface.

          atconfig: illegal parameters start=x net=y end=z.  startnet <= net <= endnet
                    One of the parameters startnet, endnet, or net is
                    invalid.  Usually means that you set a net number
                    that was not within the existing network range.
                    To fix this, edit /usr/etc/appletalk/services and
                    remove the conflicting -net argument from the
                    atconfig line for the interface.

          atconfig: SIOSETADDR failed (xx): ...
                    The ioctl to set the address failed.  Usually this
                    means that the parameters specified conflict with
                    configurations already existing on the network.

          atconfig: K-Talk kernel modules not loaded
                    If you are running a system with loadable kernel
                    modules, the loading of the kernel modules failed.
                    Check for error messages from atalkmodload.  If
                    you are not running a system with loadable kernel
                    modules, then you are running a non-AppleTalking
                    kernel.  Use mkkernel to build an AppleTalking
                    kernel, copy it to /, and reboot.

     CAVEATS
          The first interface to be successfully configured becomes
          your default interface.  This is the interface where
          AppleTalk services are registered.

     FILES
          /usr/etc/appletalk/services   The file where atconfig
                                        commands are placed.

     SEE ALSO
          atinfo(1)